@@ -162,10 +162,7 @@ ARTISTS = ["Some themes by RYX\nSome themes by Whise\nMonochrome icons by Tabber
 TRANSLATORS = "Special thanks for translators\nFull Translator list on https://translations.launchpad.net/screenlets/"
 
 # the application website
-WEBSITE = 'http://www.screenlets.org'
-
-# The Screenlets download page. Notice that if you translate this, you also have to create/translate the page for your language on the Screenlets.org (it's a Wiki!)
-THIRD_PARTY_DOWNLOAD = _("http://www.screenlets.org/index.php/Get_more_screenlets")
+WEBSITE = 'https://launchpad.net/screenlets'
 
 
 #-------------------------------------------------------------------------------
@@ -2429,7 +2426,6 @@ class Tooltip(object):
 			if name== 'width':
 				self.p_layout.set_width(width)
 			elif name == 'text':
-				value = utils.html_to_pango(value)
 				self.p_layout.set_markup(value)
 				self.label.set_markup(value)
 				ink_rect, logical_rect = self.p_layout.get_pixel_extents()
