@@ -33,7 +33,6 @@ from distutils.version import LooseVersion
 import subprocess
 import commands
 from HTMLParser import HTMLParser
-from bs4 import BeautifulSoup
 from xdg.BaseDirectory import *
 
 try:
@@ -93,15 +92,6 @@ class MLStripper(HTMLParser):
     def get_data(self):
         return ''.join(self.fed)
 
-def html_to_pango (html):	
-	"""Simple html to pango stripper."""
-	s = MLStripper()
-	s.feed(html)
-	no_html = s.get_data()
-	decoded = BeautifulSoup(no_html).get_text()
-	result = decoded.encode("UTF-8")
-	return result.strip(" \n")
-
 def is_manager_running_me():
 	"""checks if the one starting the screenlet is the screenlets manager"""
 	if str(sys.argv[0]).find('screenlets-manager') != -1:
@@ -193,23 +183,6 @@ def get_screenlet_linux_name_by_short_class_name(name):
 	"""Returns screenlet name on form 'foobar-screenlet' by shortened screenlet class name."""
 	return name.lower() + "-screenlet"
 
-def is_screenlets_ppa_enabled():
-	"""Detect if Screenlets default PPA is enabled on system."""
-	result = commands.getstatusoutput("ls /etc/apt/sources.list.d/screenlets*ppa*.list | xargs grep '^deb.*'")[0]
-	return result == 0
-
-def get_more_screenlets_ubuntu():
-	if not is_screenlets_ppa_enabled():
-		print "PPA not enabled yet"
-		if screenlets.show_question(None, _('The Screenlets PPA is not listed among Software Sources. Adding this enables installing individual screenlets from Package Manager (or Software Center) and by clicking on an AptURL on web pages like Gnome-look.org. Would you like to add the Screenlets PPA to your system?'), title=_("Do you want to enable the Screenlets PPA?")):
-			result = commands.getstatusoutput('gksudo add-apt-repository ppa:screenlets-dev/ppa && gksudo apt-get update')[0]
-			if result == 0:
-				screenlets.show_message(None, _('The Screenlets PPA added successfully.'), title=_("Success!"))
-			else:
-				screenlets.show_error(None, _('Adding the Screenlets PPA failed.'), title=_("Failed!"))
-	print "show web page anyway"
-	subprocess.Popen(["xdg-open", screenlets.THIRD_PARTY_DOWNLOAD])
-
 
 def get_translator(path):
 	"""Returns translator by screenlet class path from __file__."""
