@@ -528,18 +528,12 @@ class ScreenletsManager(object):
 		# add about/close buttons to window
 		but_about = gtk.Button(stock=gtk.STOCK_ABOUT)
 		but_close = gtk.Button(stock=gtk.STOCK_CLOSE)
-		but_download = gtk.Button(_('Get more screenlets'))
-		but_download.set_image(gtk.image_new_from_stock(gtk.STOCK_GO_DOWN, 
-			gtk.ICON_SIZE_BUTTON))
 		but_about.connect('clicked', self.button_clicked, 'about')
 		but_close.connect('clicked', self.button_clicked, 'close')
-		but_download.connect('clicked', self.button_clicked, 'download')
 		but_about.set_tooltip_text(_("Show info about this dialog ..."))
-		but_download.set_tooltip_text(_("Download more screenlets ..."))
 		but_close.set_tooltip_text(_("Close this dialog ..."))
 		action_area.set_layout(gtk.BUTTONBOX_EDGE)
 		action_area.pack_start(but_about, False, False)
-		action_area.pack_start(but_download, False, False)
 		action_area.pack_end(but_close, False, False)
 		vbox.show_all()
 		# initially create lower infobox
@@ -670,7 +664,7 @@ class ScreenletsManager(object):
 		dlg.destroy()
 		
 	def website_open(self, d, link, data):
-		subprocess.Popen(["xdg-open", "http://www.screenlets.org"])
+		subprocess.Popen(["xdg-open", "https://launchpad.net/screenlets"])
 
 	# could be used to reload screenlets on every activation (but it's a bit too much)
 	def on_active_changed(self, window, param):
@@ -956,12 +950,6 @@ class ScreenletsManager(object):
 			utils.quit_all_screenlets()
 			self.refilter_screenlets(None,'type_changed')
 
-		elif id == 'download':
-			if screenlets.UBUNTU:
-				utils.get_more_screenlets_ubuntu()
-			else:
-				subprocess.Popen(["xdg-open", screenlets.THIRD_PARTY_DOWNLOAD])
-			
 	def show_install_chose_ui(self):
 		install_rbs = gtk.VBox(False, 10)
 		install_rbs.set_border_width(10)
@@ -1208,32 +1196,37 @@ import os
 proc = os.popen("""ps axo "%p,%a" | grep "python.*screenlets-manager.py" | grep -v grep|cut -d',' -f1""").read()
 procs = proc.split('\n')
 import sys
-import wnck
 try:
-	wnck.set_client_type(wnck.CLIENT_TYPE_PAGER)
-except AttributeError:
-	print "Error: Failed to set libwnck client type, window " \
-				"activation may not work"
-if len(procs) > 2:
-	print "Manager already started"
-	screen = wnck.screen_get_default()
-	while gtk.events_pending():
-		gtk.main_iteration()
-	wins = screen.get_windows_stacked()
+	import wnck
+	try:
+		wnck.set_client_type(wnck.CLIENT_TYPE_PAGER)
+	except AttributeError:
+		print "Error: Failed to set libwnck client type, window " \
+					"activation may not work"
+	if len(procs) > 2:
+		print "Manager already started"
+		screen = wnck.screen_get_default()
+		while gtk.events_pending():
+			gtk.main_iteration()
+		wins = screen.get_windows_stacked()
+		
+		for win in wins:
+			name = win.get_name()
+			if name == gettext.gettext('Screenlets Manager'):
 	
-	for win in wins:
-		name = win.get_name()
-		if name == gettext.gettext('Screenlets Manager'):
-
-			if win and win.is_active():
-				sys.exit(1)
-			elif win and win.is_minimized():
-				win.unminimize(1)
-			elif win and win.is_active() == False:
-				win.activate(1)
-
-
-	sys.exit(1)
+				if win and win.is_active():
+					sys.exit(1)
+				elif win and win.is_minimized():
+					win.unminimize(1)
+				elif win and win.is_active() == False:
+					win.activate(1)
+	
+	
+		sys.exit(1)
+except ImportError:
+	if len(procs) > 2:
+		print "Manager already started"
+		sys.exit(1)
 
 
 app = ScreenletsManager()
